12 Oct
2020
12 Oct
'20
4:01 a.m.
Thanks Malahal, ntirpc window size fixes are working. But we are seeing a performance degradation on v3 when compared with v2.5. iozone taking 50% more time to complete on the same setup with v3 version. IO operations with bigger block sizes - seems like having the impact. With 3.3 – after fix real 36m37.985s user 0m1.974s sys 1m33.561s v2.5 – working version real 23m21.187s user 0m1.797s sys 1m16.537s Please let me if you need anything more from my setup like traces...to get hold of the issue